@@ -85,6 +85,21 @@ rxtracto <- function(dataInfo, parameter = NULL, xcoord=NULL, ycoord = NULL,
     print(dimLengths)
     stop("Correct Input Vectors")
   }
+
+  # check "radius" input
+  if ( (length(xlen) > 1) && (length(xlen) != length(xcoord))) {
+    stop('xlen is of size greater than one but not equal to length of xccoord')
+  }
+  if ( (length(ylen) > 1) && (length(ylen) != length(ycoord))) {
+    stop('ylen is of size greater than one but not equal to length of yccoord')
+  }
+  if ( (!is.null(zcoord)) && length(xlen)  > 1) {
+    if (length(zlen) == 1)  {
+      message('warning - zlen has a single value')
+      message('xlen and ylen have length greater than 1')
+      message('zlen will be extended to be same length with repeated value')
+    }
+  }
   urlbase <- checkInput(dataInfo1, parameter, urlbase, callDims)
 
   # Check and readjust coordinate variables ---------------------------------
@@ -113,7 +128,11 @@ rxtracto <- function(dataInfo, parameter = NULL, xcoord=NULL, ycoord = NULL,
   } else {
     xrad <- xlen
     yrad <- ylen
-    zrad <- zlen
+    if ( (!is.null(zcoord)) && (length(zlen) == 1)) {
+        zrad <- rep(zlen, length(zcoord))
+    } else {
+        zrad <- zlen
+    }
   }
 
 
@@ -224,7 +243,9 @@ oldDataFrame <- out_dataframe[1, ]
      lon_signs <- sign(erddapCoords$erddapXcoord)
      if (lon_signs[1] != lon_signs[2]) {cross_dateline_180_local <- TRUE}
        if (cross_dateline_180_local) {
-       xcoord_temp <- c(erddapCoords$erddapXcoord[1], 180)
+       # upper_bound <- round(max(dataCoordList$longitude), 3)
+       upper_bound <- max(dataCoordList$longitude) - 0.0001
+       xcoord_temp <- c(erddapCoords$erddapXcoord[1], upper_bound)
        extract1 <- data_extract_read(dataInfo1, callDims, urlbase,
                                      xName, yName, zName, tName, parameter,
                                      xcoord_temp, erddapCoords$erddapYcoord,
@@ -240,7 +261,9 @@ oldDataFrame <- out_dataframe[1, ]
          rerddap::cache_delete(extract1)
          return(out_dataframe)
        }
-       xcoord_temp <- c(min(dataCoordList$longitude), erddapCoords$erddapXcoord[2])
+       # lower_bound <- round(min(dataCoordList$longitude), 3)
+       lower_bound <- min(dataCoordList$longitude) + 0.0001
+       xcoord_temp <- c(lower_bound, erddapCoords$erddapXcoord[2])
        extract2 <- data_extract_read(dataInfo1, callDims, urlbase,
                                      xName, yName, zName, tName, parameter,
                                      xcoord_temp, erddapCoords$erddapYcoord,
